# Examples 📖

## Examples by LLM API Providers 🤖

| API Provider | Example File |
|--------------|--------------|
| Anthropic    | [anthropic_instruction_dataset_example.py](https://github.com/Shekswess/synthgenai/blob/main/examples/anthropic_instruction_dataset_example.py) |
| Azure AI     | [azure_ai_preference_dataset_example.py](https://github.com/Shekswess/synthgenai/blob/main/examples/azure_ai_preference_dataset_example.py) |
| Azure        | [azure_summarization_dataset_example.py](https://github.com/Shekswess/synthgenai/blob/main/examples/azure_summarization_dataset_example.py) |
| Bedrock      | [bedrock_raw_dataset_example.py](https://github.com/Shekswess/synthgenai/blob/main/examples/bedrock_raw_dataset_example.py) |
| Gemini       | [gemini_langfuse_raw_dataset_example.py](https://github.com/Shekswess/synthgenai/blob/main/examples/gemini_langfuse_raw_dataset_example.py) |
| Groq         | [groq_preference_dataset_example.py](https://github.com/Shekswess/synthgenai/blob/main/examples/groq_preference_dataset_example.py) |
| Hugging Face | [huggingface_instruction_dataset_example.py](https://github.com/Shekswess/synthgenai/blob/main/examples/huggingface_instruction_dataset_example.py) |
| Mistral      | [mistral_preference_dataset_example.py](https://github.com/Shekswess/synthgenai/blob/main/examples/mistral_preference_dataset_example.py) |
| Ollama       | [ollama_preference_dataset_example.py](https://github.com/Shekswess/synthgenai/blob/main/examples/ollama_preference_dataset_example.py) |
| OpenAI       | [openai_raw_dataset_example.py](https://github.com/Shekswess/synthgenai/blob/main/examples/openai_raw_dataset_example.py) |
| SageMaker    | [sagemaker_summarization_dataset_example.py](https://github.com/Shekswess/synthgenai/blob/main/examples/sagemaker_summarization_dataset_example.py) |
| Vertex AI    | [vertex_ai_text_classification_dataset_example.py](https://github.com/Shekswess/synthgenai/blob/main/examples/vertex_ai_text_classification_dataset_example.py) |
| vLLM         | [vllm_sentiment_analysis_dataset_example.py](https://github.com/Shekswess/synthgenai/blob/main/examples/vllm_sentiment_analysis_dataset_example.py) |

## Examples by Dataset Types 📚

| Dataset Type           | Example File |
|------------------------|--------------|
| Instruction Dataset    | [anthropic_instruction_dataset_example.py](https://github.com/Shekswess/synthgenai/blob/main/examples/anthropic_instruction_dataset_example.py), [huggingface_instruction_dataset_example.py](https://github.com/Shekswess/synthgenai/blob/main/examples/huggingface_instruction_dataset_example.py) |
| Preference Dataset     | [azure_ai_preference_dataset_example.py](https://github.com/Shekswess/synthgenai/blob/main/examples/azure_ai_preference_dataset_example.py), [groq_preference_dataset_example.py](https://github.com/Shekswess/synthgenai/blob/main/examples/groq_preference_dataset_example.py), [mistral_preference_dataset_example.py](https://github.com/Shekswess/synthgenai/blob/main/examples/mistral_preference_dataset_example.py), [ollama_preference_dataset_example.py](https://github.com/Shekswess/synthgenai/blob/main/examples/ollama_preference_dataset_example.py) |
| Raw Dataset            | [bedrock_raw_dataset_example.py](https://github.com/Shekswess/synthgenai/blob/main/examples/bedrock_raw_dataset_example.py), [gemini_langfuse_raw_dataset_example.py](https://github.com/Shekswess/synthgenai/blob/main/examples/gemini_langfuse_raw_dataset_example.py), [openai_raw_dataset_example.py](https://github.com/Shekswess/synthgenai/blob/main/examples/openai_raw_dataset_example.py) |
| Sentiment Analysis     | [vllm_sentiment_analysis_dataset_example.py](https://github.com/Shekswess/synthgenai/blob/main/examples/vllm_sentiment_analysis_dataset_example.py) |
| Summarization Dataset  | [azure_summarization_dataset_example.py](https://github.com/Shekswess/synthgenai/blob/main/examples/azure_summarization_dataset_example.py), [sagemaker_summarization_dataset_example.py](https://github.com/Shekswess/synthgenai/blob/main/examples/sagemaker_summarization_dataset_example.py) |
| Text Classification    | [vertex_ai_text_classification_dataset_example.py](https://github.com/Shekswess/synthgenai/blob/main/examples/vertex_ai_text_classification_dataset_example.py) |

